@@ -4,17 +4,17 @@
 ## Date Created: 2015/08/26
 ## Date Modified: 2015/08/26
 ## Purpose: Function to try parameters and
-##          get estimates of performance
+## get estimates of performance
 #############################################
 
-run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
-                     ssdmat, group_pop, counties, names, maxiterrsg, report_all,
+run_sims <- function(i, params, map, nsims, init_plan,
+                     group_pop, counties, names, maxiterrsg, report_all,
                      adapt_lambda, adapt_eprob,
-                     nstartval_store, maxdist_startval, logarg){
+                     nstartval_store, maxdist_startval, logarg) {
 
     ## Get this iteration
     p_sub <- params %>% dplyr::slice(i)
-    if(logarg){
+    if (logarg) {
         sink(paste0("log_", i, ".txt"))
         cat("Parameter Values:\n")
         cat(c(p_sub))
@@ -22,127 +22,114 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
     }
 
     ## Set parameter values
-    if("eprob" %in% names){
+    if ("eprob" %in% names) {
         eprob <- p_sub$eprob
-    }else{
+    } else {
         eprob <- 0.05
     }
 
-    if("lambda" %in% names){
+    if ("lambda" %in% names) {
         lambda <- p_sub$eprob
-    }else{
+    } else {
         lambda <- 0
     }
 
-    if(!("pop_tol" %in% names)){
+    if (!("pop_tol" %in% names)) {
         pop_tol <- 100
-    }else{
+    } else {
         pop_tol <- p_sub$pop_tol
     }
 
     ## Set constraints
-    constraintvec <- c()
-    weightvec <- c()
-    addweights <- FALSE
-    if("weight_population" %in% names){
-        constraintvec <- c(constraintvec, "population")
-        weightvec <- c(weightvec, p_sub$weight_population)
-        addweights <- TRUE
+    constr <- redist_constr(map)
+    if ("weight_population" %in% names) {
+        constr <- constr %>%
+            add_constr_pop_dev(strength = p_sub$weight_population)
     }
-    if("weight_compact" %in% names){
-        constraintvec <- c(constraintvec, "compact")
-        weightvec <- c(weightvec, p_sub$weight_compact)
-        addweights <- TRUE
+    if ("weight_compact" %in% names) {
+        constr <- constr %>%
+            add_constr_edges_rem(strength = p_sub$weight_compact)
     }
-    if("weight_segregation" %in% names){
-        constraintvec <- c(constraintvec, "segregation")
-        weightvec <- c(weightvec, p_sub$weight_segregation)
-        addweights <- TRUE
+    if ("weight_segregation" %in% names) {
+        constr <- constr %>%
+            add_constr_segregation(strength = p_sub$weight_segregation,
+                group_pop = group_pop)
     }
-    if("weight_similarity" %in% names){
-        constraintvec <- c(constraintvec, "similarity")
-        weightvec <- c(weightvec, p_sub$weight_similarity)
-        addweights <- TRUE
+    if ("weight_similarity" %in% names) {
+        constr <- constr %>%
+            add_constr_status_quo(strength = p_sub$weight_similarity, current = init_plan)
     }
-    if("weight_countysplit" %in% names){
-        constraintvec <- c(constraintvec, "countysplit")
-        weightvec <- c(weightvec, p_sub$weight_countysplit)
-        addweights <- TRUE
+    if ("weight_countysplit" %in% names) {
+        constr <- constr %>%
+            add_constr_splits(strength = p_sub$weight_countysplit, admin = counties)
     }
-    if(addweights == FALSE){
-        constraintvec <- NULL
-        weightvec <- NULL
-    }
-
     ## Run siulations
-    out <- redist.flip(adj = adj, total_pop = total_pop, nsims = nsims,
-                       ndists = ndists, ssdmat = ssdmat,
-                       group_pop = group_pop,
-                       counties = counties,
-                       init_plan = init_plan, eprob = eprob, lambda = lambda,
-                       pop_tol = pop_tol,
-                       constraint = constraintvec,
-                       constraintweights = weightvec,
-                       maxiterrsg = maxiterrsg,
-                       adapt_lambda = adapt_lambda,
-                       adapt_eprob = adapt_eprob)
-    if(adapt_eprob){
-        final_eprob <- out$final_eprob
+    out <- redist_flip(map %>% set_pop_tol(pop_tol),
+        nsims = nsims,
+        init_plan = init_plan,
+        eprob = eprob,
+        lambda = lambda,
+        constraints = constr,
+        adapt_lambda = adapt_lambda,
+        adapt_eprob = adapt_eprob) %>%
+        subset_sampled()
+    if (adapt_eprob) {
+        final_eprob <- attr(out, "final_eprob")
     }
-    if(adapt_lambda){
-        final_lambda <- out$final_lambda
+    if (adapt_lambda) {
+        final_lambda <- attr(out, "final_lambda")
     }
 
     ## Sample districts for use as starting values
     ## Divide equally by distance
-    inds <- which(1 - out$distance_original < maxdist_startval)
+    inds <- which(1 - attr(out, "distance_original") < maxdist_startval)
     cuts <- c(0, round(quantile(1:length(inds), (1:nstartval_store)/nstartval_store)))
-    if(length(inds) == 0){
+    if (length(inds) == 0) {
         cat(paste0("No maps available under parameter set ", i, ".\n"))
         startval <- NULL
-    }else{
-        startval <- matrix(NA, nrow(out$plans), nstartval_store)
-        for(i in 1:nstartval_store){
-            sub <- inds[inds > cuts[i] & inds <= cuts[i+1]]
-            startval[,i] <- out$plans[,sample(sub, 1)]
+    } else {
+        startval <- matrix(NA, nrow(get_plans_matrix(out)), nstartval_store)
+        for (i in 1:nstartval_store) {
+            sub <- inds[inds > cuts[i] & inds <= cuts[i + 1]]
+            startval[, i] <- get_plans_matrix(out)[, sample(sub, 1)]
         }
         startval <- as.matrix(startval)
     }
 
     ## Get quantiles
-    quant <- floor(nsims / 4)
+    quant <- floor(nsims/4)
     q1 <- 1:quant
     q2 <- (quant + 1):(2*quant)
-    q3 <- (2*quant + 1):(3 * quant)
+    q3 <- (2*quant + 1):(3*quant)
     q4 <- (3*quant + 1):nsims
 
     ## Check acceptance rate
-    mh_acceptance <- round(sum(out$mhdecisions) / length(out$mhdecisions),
-                           digits = 3)
+    mh_acceptance <- round(sum(out$mhdecisions, na.rm = TRUE)/length(stats::na.omit(out$mhdecisions)),
+        digits = 3)
 
     ## Check population parity
-    pop_parity <- round(mean(out$distance_parity), digits = 3)
-    med_pop_parity <- round(median(out$distance_parity), digits = 3)
-    range_pop_parity <- round(range(out$distance_parity), digits = 3)
-    q1_pop_median <- round(median(out$distance_parity[q1]), digits = 3)
-    q2_pop_median <- round(median(out$distance_parity[q2]), digits = 3)
-    q3_pop_median <- round(median(out$distance_parity[q3]), digits = 3)
-    q4_pop_median <- round(median(out$distance_parity[q4]), digits = 3)
+    pop_parity <- round(mean(out$distance_parity, na.rm = TRUE), digits = 3)
+    med_pop_parity <- round(median(out$distance_parity, na.rm = TRUE), digits = 3)
+    range_pop_parity <- round(range(out$distance_parity, na.rm = TRUE), digits = 3)
+    q1_pop_median <- round(median(out$distance_parity[q1], na.rm = TRUE), digits = 3)
+    q2_pop_median <- round(median(out$distance_parity[q2], na.rm = TRUE), digits = 3)
+    q3_pop_median <- round(median(out$distance_parity[q3], na.rm = TRUE), digits = 3)
+    q4_pop_median <- round(median(out$distance_parity[q4], na.rm = TRUE), digits = 3)
 
     ## Check distance to original
-    dist_orig <- round(mean(out$distance_original), digits = 3)
-    med_dist_orig <- round(median(out$distance_original), digits = 3)
-    range_dist_orig <- round(range(out$distance_original), digits = 3)
-    q1_dist_median <- round(median(out$distance_original[q1]), digits = 3)
-    q2_dist_median <- round(median(out$distance_original[q2]), digits = 3)
-    q3_dist_median <- round(median(out$distance_original[q3]), digits = 3)
-    q4_dist_median <- round(median(out$distance_original[q4]), digits = 3)
+    dist_orig <- round(mean(attr(out, "distance_original"), na.rm = TRUE), digits = 3)
+    med_dist_orig <- round(median(attr(out, "distance_original"), na.rm = TRUE), digits = 3)
+    range_dist_orig <- round(range(attr(out, "distance_original"), na.rm = TRUE), digits = 3)
+    q1_dist_median <- round(median(attr(out, "distance_original")[q1], na.rm = TRUE), digits = 3)
+    q2_dist_median <- round(median(attr(out, "distance_original")[q2], na.rm = TRUE), digits = 3)
+    q3_dist_median <- round(median(attr(out, "distance_original")[q3], na.rm = TRUE), digits = 3)
+    q4_dist_median <- round(median(attr(out, "distance_original")[q4], na.rm = TRUE), digits = 3)
 
     ## Share of counties split
-    if(!is.null(counties)){
-        ncounties_split <- unlist(lapply(1:nsims, function(x){
-            cd_assign <- out$plans[,x]
-            return(sum(tapply(cd_assign, counties, function(y){ifelse(length(unique(y)) > 1, 1, 0)})))
+    if (!is.null(counties)) {
+        ncounties_split <- unlist(lapply(1:nsims, function(x) {
+            cd_assign <- out$plans[, x]
+            return(sum(tapply(cd_assign, counties, function(y) {ifelse(length(unique(y)) > 1, 1, 0)})))
         }))
         starting_county_split <- ncounties_split[1]
         q1_countysplit_median <- median(ncounties_split[q1])
@@ -155,35 +142,35 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
     ## Report statistics
     ## -----------------
     out <- paste("## -------------------------------------\n",
-                 "## -------------------------------------\n",
-                 "## Parameter Values for Simulation", i, "\n")
-    if(!adapt_eprob){
+        "## -------------------------------------\n",
+        "## Parameter Values for Simulation", i, "\n")
+    if (!adapt_eprob) {
         out <- paste0(out, "## Edgecut probability = ", eprob, "\n")
-    }else{
+    } else {
         out <- paste0(out, "## Final adaptive edgecut probability = ",
-                      final_eprob, "\n")
+            final_eprob, "\n")
     }
-    if(!adapt_lambda){
+    if (!adapt_lambda) {
         out <- paste0(out, "## Lambda = ", lambda, "\n")
-    }else{
+    } else {
         out <- paste0(out, "## Final adaptive lambda = ", final_lambda, "\n")
     }
-    if(pop_tol != 100){
+    if (pop_tol != 100) {
         out <- paste0(out, "## Hard population constraint = ", pop_tol, "\n")
-    }else{
+    } else {
         out <- paste0(out, "## No hard population constraint applied\n")
     }
-    if(!is.null(constraintvec)){
-        out <- paste0(out, "## Setting constraints on ", as.character(constraintvec), "\n",
-                      "## Weights  = ", weightvec, "\n")
-    }else{
-        out <- paste0(out, "## Not setting any soft constraints\n")
-    }
+    # if(!is.null(constraintvec)){
+    # out <- paste0(out, "## Setting constraints on ", as.character(constraintvec), "\n",
+    # "## Weights  = ", weightvec, "\n")
+    # }else{
+    # out <- paste0(out, "## Not setting any soft constraints\n")
+    # }
     out <- paste0(out,
-                 "## -------------------------------------\n",
-                 "## Diagnostics:\n",
-                 "## Metropolis-Hastings Acceptance Ratio = ", mh_acceptance, "\n")
-    if("population" %in% constraintvec | report_all == TRUE){
+        "## -------------------------------------\n",
+        "## Diagnostics:\n",
+        "## Metropolis-Hastings Acceptance Ratio = ", mh_acceptance, "\n")
+    if (report_all == TRUE) {
         out <- paste0(
             out, "## Mean population parity distance = ",
             pop_parity, "\n",
@@ -194,10 +181,10 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
             "\n",
             "## MCMC Iteration quantiles of population parity median = ",
             paste(q1_pop_median, q2_pop_median,
-                  q3_pop_median, q4_pop_median, sep = " "),
+                q3_pop_median, q4_pop_median, sep = " "),
             "\n")
     }
-    if("similarity" %in% constraintvec | report_all == TRUE){
+    if (report_all == TRUE) {
         out <- paste0(
             out,
             "\n## Mean share of geographies equal to initial assignment = ",
@@ -208,11 +195,11 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
             paste(range_dist_orig, collapse = " "), "\n",
             "## MCMC Iteration quantiles of geography distance to initial assignment = ",
             paste(q1_dist_median, q2_dist_median,
-                  q3_dist_median, q4_dist_median, sep = " "),
+                q3_dist_median, q4_dist_median, sep = " "),
             "\n")
     }
-    if(!is.null(counties)){
-        if("countysplit" %in% constraintvec | report_all == TRUE){
+    if (!is.null(counties)) {
+        if (report_all == TRUE) {
             out <- paste0(
                 out,
                 "\n## Median number of counties split = ",
@@ -229,9 +216,9 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
         }
     }
     out <- paste0(out,
-                  "## -------------------------------------\n",
-                  "## -------------------------------------\n\n")
-    if(logarg){
+        "## -------------------------------------\n",
+        "## -------------------------------------\n\n")
+    if (logarg) {
         sink()
     }
 
@@ -242,15 +229,10 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
 #' Run parameter testing for \code{redist.flip}
 #'
 #' \code{redist.findparams} is used to find optimal parameter values of
-#' \code{redist.flip} for a given map.
+#' \code{redist_flip} for a given map.
 #'
-#' @param adj An adjacency matrix, list, or object of class
-#' "SpatialPolygonsDataFrame."
-#' @param total_pop A vector containing the populations of each
-#' geographic unit.
+#' @param map A \code{\link{redist_map}} object.
 #' @param nsims The number of simulations run before a save point.
-#' @param ndists The number of congressional districts.
-#' The default is \code{NULL}.
 #' @param init_plan A vector containing the congressional district labels
 #' of each geographic unit. The default is \code{NULL}. If not provided, random
 #' and contiguous congressional district assignments will be generated using \code{redist.rsg}.
@@ -307,26 +289,29 @@ run_sims <- function(i, params, adj, total_pop, nsims, ndists, init_plan,
 #'
 #' params <- expand.grid(eprob = c(.01, .05, .1))
 #'
+#' # Make map
+#' map_fl <- redist_map(fl25, ndists = 3, pop_tol = 0.2)
 #' ## Run the algorithm
-#' redist.findparams(adj = fl25_adj, total_pop = fl25$pop,
-#'                   init_plan = init_plan, nsims = 10000, params = params)
+#' redist.findparams(map_fl,
+#'     init_plan = init_plan, nsims = 10000, params = params)
 #' }
 #' @concept prepare
 #' @export
-redist.findparams <- function(adj, total_pop,
-                              nsims, ndists = NULL, init_plan = NULL,
+redist.findparams <- function(map,
+                              nsims,
+                              init_plan = NULL,
                               adapt_lambda = FALSE, adapt_eprob = FALSE,
                               params, ssdmat = NULL,
                               group_pop = NULL, counties = NULL,
                               nstartval_store = 1, maxdist_startval = 100,
                               maxiterrsg = 5000, report_all = TRUE,
                               parallel = FALSE, ncores = NULL,
-                              log = FALSE, verbose = TRUE){
+                              log = FALSE, verbose = TRUE) {
     ## Get number of trial parameter values to test
     trials <- nrow(params)
 
     ## Starting statement
-    if(verbose){
+    if (verbose) {
         cat(paste("## ------------------------------\n",
             "## redist.findparams(): Parameter tuning for redist.flip()\n",
             "## Searching over", trials, "parameter combinations\n",
@@ -336,96 +321,87 @@ redist.findparams <- function(adj, total_pop,
     ## Get parameters in params
     valid_names <- c("eprob", "lambda", "pop_tol", "weight_compact", "weight_population", "weight_segregation", "weight_similarity", "weight_countysplit")
     names <- names(params)
-    if(sum(names %in% valid_names) < length(names)){
+    if (sum(names %in% valid_names) < length(names)) {
         invalid_name <- names[!(names %in% valid_names)]
-        stop(paste(invalid_name, "is not a valid params input. Please see documentation.\n", sep = " "))
+        cli_abort(paste(invalid_name, "is not a valid params input. Please see documentation.\n", sep = " "))
     }
 
     ## Check ndists, init_plan
-    if(is.null(ndists) & is.null(init_plan)){
-        stop("Please either supply a vector of starting congressional district assignments in `init_plan' or a target number of congressional districts in `ndists`")
-    }
-    if(!is.null(init_plan)){
-        ndists <- length(unique(init_plan))
-    }
-    if(sum("lambda" %in% names & adapt_lambda) > 0){
-        warning("You have specified a grid of lambda values to search and set `adapt_lambda` to TRUE. Setting `adapt_lambda` to FALSE.")
+    if (sum("lambda" %in% names & adapt_lambda) > 0) {
+        cli_warn("You have specified a grid of lambda values to search and set `adapt_lambda` to TRUE. Setting `adapt_lambda` to FALSE.")
         adapt_lambda <- FALSE
     }
-    if(sum("eprob" %in% names & adapt_eprob) > 0){
-        warning("You have specified a grid of eprob values to search and set `adapt_eprob` to TRUE. Setting `adapt_eprob` to FALSE.")
+    if (sum("eprob" %in% names & adapt_eprob) > 0) {
+        cli_warn("You have specified a grid of eprob values to search and set `adapt_eprob` to TRUE. Setting `adapt_eprob` to FALSE.")
         adapt_eprob <- FALSE
     }
-    if("weight_segregation" %in% names & is.null(group_pop)){
-        stop("If constraining on segregation, please provide a vector of group population.")
+    if ("weight_segregation" %in% names & is.null(group_pop)) {
+        cli_abort("If constraining on segregation, please provide a vector of group population.")
     }
-    if("weight_compact" %in% names & is.null(ssdmat)){
-        stop("If constraining on compactness, please provide a distances matrix.")
+    if ("weight_compact" %in% names & is.null(ssdmat)) {
+        cli_abort("If constraining on compactness, please provide a distances matrix.")
     }
-    if("weight_similarity" %in% names & is.null(init_plan)){
-        stop("If constraining on similarity, please provide a vector of initial congressional district assignments.")
+    if ("weight_similarity" %in% names & is.null(init_plan)) {
+        cli_abort("If constraining on similarity, please provide a vector of initial congressional district assignments.")
     }
-    if("weight_countysplit" %in% names & is.null(counties)){
-        stop("If constraining the number of county splits, please provide a vector of county assignments.")
+    if ("weight_countysplit" %in% names & is.null(counties)) {
+        cli_abort("If constraining the number of county splits, please provide a vector of county assignments.")
     }
 
-    if(parallel){ ## Parallel
+    if (parallel) { ## Parallel
 
         ## Check to see if threads declared
-        if(is.null(ncores)){
-            stop("If parallelizing, please declare the number of threads")
+        if (is.null(ncores)) {
+            cli_abort("If parallelizing, please declare the number of threads")
         }
 
         ## Statement initializing parallelization
-        if(verbose){
+        if (verbose) {
             cat(paste("## -----------------------------\n",
                 "## Parallelizing over", ncores, "processors\n",
                 "## -----------------------------\n\n", sep = " "))
         }
 
         ## Set parallel environment
-        if(verbose){
+        if (verbose) {
             cl <- makeCluster(ncores, outfile = "")
-        }else{
+        } else {
             cl <- makeCluster(ncores)
         }
-        registerDoParallel(cl)
+        doParallel::registerDoParallel(cl)
 
         ## Execute foreach loop
-        ret <- foreach(i = 1:trials, .verbose = verbose) %dopar% {
+        ret <- foreach(i = 1:trials, .verbose = verbose) %dorng% {
 
             ## Run simulations
-            out <- run_sims(i, params, adj, total_pop, nsims, ndists, init_plan,
-                            ssdmat, group_pop, counties, names, maxiterrsg, report_all,
-                            adapt_lambda, adapt_eprob,
-                            nstartval_store, maxdist_startval, log)
-
-            ## Return values
-            return(out)
+            run_sims(i, params, map, nsims, init_plan,
+                group_pop, counties, names, maxiterrsg, report_all,
+                adapt_lambda, adapt_eprob,
+                nstartval_store, maxdist_startval, log)
 
         }
 
         printout <- c()
         startval <- vector(mode = "list", length = trials)
-        for(i in 1:trials){
+        for (i in 1:trials) {
             printout <- paste(printout, ret[[i]]$printout)
             startval[[i]] <- ret[[i]]$startval
         }
 
-    }else{ ## Sequential
+    } else { ## Sequential
 
         ## Create container for report
         printout <- c()
         startval <- vector(mode = "list", length = trials)
 
         ## Start loop over parameter values
-        for(i in 1:trials){
+        for (i in 1:trials) {
 
             ## Run simulations
-            out <- run_sims(i = i, params = params, adj, total_pop, nsims, ndists, init_plan,
-                            ssdmat, group_pop, counties, names, maxiterrsg, report_all,
-                            adapt_lambda, adapt_eprob,
-                            nstartval_store, maxdist_startval, log)
+            out <- run_sims(i = i, params = params, map = map, nsims = nsims, init_plan,
+                group_pop, counties, names, maxiterrsg, report_all,
+                adapt_lambda, adapt_eprob,
+                nstartval_store, maxdist_startval, logarg = log)
 
             ## Add to printout
             printout <- paste(printout, out$printout)
@@ -435,7 +411,7 @@ redist.findparams <- function(adj, total_pop,
 
     }
 
-    if(parallel){
+    if (parallel) {
         stopCluster(cl)
     }
 
